/**
 ******************************************************************************
 *
 * @file        MG82F6P32_GPLCRC_DRV.c
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     V1.00
 * @date        2024/03/28
 * @author      Megawin Software Center
 * @copyright   Copyright (c) 2019 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#include "MG82F6P32_CONFIG.h"

/**
*******************************************************************************
* @brief       Set GPL CRC16 Seed.
* @details     
* @return      
* @note        None
* @par         Example
* @code
               DRV_CRC16_Seed(0,0)
 * @endcode
*******************************************************************************
*/
void DRV_CRC16_Seed(uint8_t CRC0SH_t,uint8_t CRC0SL_t)
{
    __DRV_GPLCRC_SetCRC0SH(CRC0SH_t);//CRC seed High byte
    __DRV_GPLCRC_SetCRC0SL(CRC0SL_t);//CRC seed Low byte
    __DRV_GPGCRC_SelectCRC0DI();
}

/**
*******************************************************************************
* @brief       Set GPL CRC32 Seed.
* @details     
* @return      
* @note        None
* @par         Example
* @code
               DRV_CRC32_Seed(0xFF,0xFF,0xFF,0xFF)
 * @endcode
*******************************************************************************
*/
void DRV_CRC32_Seed(uint8_t CRC0S3_t,uint8_t CRC0S2_t,uint8_t CRC0SH_t,uint8_t CRC0SL_t)
{
	  __DRV_GPLCRC_SetCRC0S3(CRC0S3_t);//
	  __DRV_GPLCRC_SetCRC0S2(CRC0S2_t);//
    __DRV_GPLCRC_SetCRC0SH(CRC0SH_t);//CRC seed High byte
    __DRV_GPLCRC_SetCRC0SL(CRC0SL_t);//CRC seed Low byte
    __DRV_GPGCRC_SelectCRC0DI();
}
