/**
 ******************************************************************************
 *
 * @file        MG82F6P32_COMMON_DRV.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     V1.00
 * @date        2024/03/13
 * @copyright   Copyright (c) 2019 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#ifndef _MG82F6P32_COMMON_DRV_H
#define _MG82F6P32_COMMON_DRV_H



/// @cond Parameter_definition

//!@{
//! defgroup IFMT Commands
//IFMT Commands
#define IFMT_STANDBY                        0x00
#define IFMT_PAGE_P_WRITE                   0x04
#define IFMT_PAGE_P_READ                    0x05
/// @endcond

/**
 *******************************************************************************
 * @brief       Switch the SFR page.
 * @details
 * @param[in]   __Page__ : specifies the page index.
 * @return      None
 * @note
 * @par         Example
 * @code
 *      __DRV_SFR_PageIndex(P6M0_Page);
 * @endcode
 *******************************************************************************
 */

#define __DRV_SFR_PageIndex(__Page__)\
    MWT(\
        SFRPI = __Page__;\
    )


void DRV_PageP_WriteWithoutIT(uint8_t ADDR, uint8_t DATA);
void DRV_PageP_Write(uint8_t ADDR, uint8_t DATA);
uint8_t DRV_PageP_ReadWithoutIT(uint8_t ADDR);
uint8_t DRV_PageP_Read(uint8_t ADDR);


#endif  //_MG82F6P32_COMMON_DRV_H

