/**
 ******************************************************************************
 *
 * @file        MG82F6P32_CONFIG.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     V1.00
 * @date        2024/03/26
 * @copyright   Copyright (c) 2019 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#ifndef _MG82F6P32_CONFIG_H
#define _MG82F6P32_CONFIG_H


#include <intrins.h>
#include "REG_MG82F6P32.h"
#include "TYPEDEF.h"
#include "stdio.h"

/**
 ******************************************************************************
 * do-while template
 ******************************************************************************
 */
#define MWT( __stuff__ )  do { __stuff__ } while (0)


/**
 ******************************************************************************
 * Headers
 ******************************************************************************
 */

//COMMON
#include "MG82F6P32_COMMON_DRV.h"
//#include "MG82F6P32_COMMON_MID.h"
#include "MG82F6P32_WIZARD.h"

//Ch8. DMA
#include "MG82F6P32_DMA_DRV.h"
//#include "MG82F6P32_DMA_MID.h"

//Ch9. System Clock
#include "MG82F6P32_CLK_DRV.h"
#include "MG82F6P32_CLK_MID.h"

//Ch10. Watch Dog Timer (WDT)
#include "MG82F6P32_WDT_DRV.h"
//#include "MG82F6P32_WDT_MID.h"

//Ch11. Real-Time-Clock (RTC)/System-Timer
#include "MG82F6P32_RTC_DRV.h"
//#include "MG82F6P32_RTC_MID.h"

//Ch12. System Reset
#include "MG82F6P32_RST_DRV.h"
//#include "MG82F6P32_RST_MID.h"

//Ch13. Power Management
#include "MG82F6P32_PW_DRV.h"
//#include "MG82F6P32_PW_MID.h"

//Ch14. Configurable I/O Ports (GPIO)
#include "MG82F6P32_GPIO_DRV.h"
//#include "MG82F6P32_GPIO_MID.h"

//Ch15. Interrupt
#include "MG82F6P32_INT_DRV.h"
//#include "MG82F6P32_INT_MID.h"
#include "MG82F6P32_INT_VECTOR.h"

//Ch16. Timers/Counters
#include "MG82F6P32_TIMER_DRV.h"
//#include "MG82F6P32_TIMER_MID.h"

//Ch17. PWM Timer (PTM0)
#include "MG82F6P32_PTM0_DRV.h"
//#include "MG82F6P32_PTM0_MID.h"

//Ch18. Programmable Counter Array (PCA1)
#include "MG82F6P32_PCA1_DRV.h"
//#include "MG82F6P32_PCA1_MID.h"

//Ch19,20. SerialPort0/1 (UART0/UART1)
#include "MG82F6P32_UART0_DRV.h"
#include "MG82F6P32_UART0_MID.h"
#include "MG82F6P32_UART1_DRV.h"
#include "MG82F6P32_UART1_MID.h"
#include "MG82F6P32_UARTx_ARGB_DRV.h"
#include "MG82F6P32_UARTx_ARGB_MID.h"

//Ch21. Serial Peripheral Interface (SPI)
#include "MG82F6P32_SPI_DRV.h"
#include "MG82F6P32_SPI_MID.h"

//Ch22. Two Wire serial Interface (TWI0/I2C0 & TWI1/I2C1)
#include "MG82F6P32_I2C0_DRV.h"
//#include "MG82F6P32_I2C0_MID.h"
#include "MG82F6P32_I2C1_DRV.h"
//#include "MG82F6P32_I2C1_MID.h"

//Ch23. Serial Interface Detection (STWI/SI2C)
#include "MG82F6P32_SI2C_DRV.h"
//#include "MG82F6P32_SI2C_MID.h"

//Ch24. Beeper
#include "MG82F6P32_BEEPER_DRV.h"
//#include "MG82F6P32_BEEPER_MID.h"

//Ch25. Keypad Interrupt (KBI)
#include "MG82F6P32_KBI_DRV.h"
//#include "MG82F6P32_KBI_MID.h"

//Ch26. General Purpose Logic (GPL-CRC)
#include "MG82F6P32_GPLCRC_DRV.h"
//#include "MG82F6P32_GPL_MID.h"

//Ch27. Operational Amplifiers (OPA0/OPA1)
#include "MG82F6P32_OPA0_DRV.h"
#include "MG82F6P32_OPA1_DRV.h"
#include "MG82F6P32_OPAx_DRV.h"

//Ch28. Programmable Gain Amplifier, PGA
#include "MG82F6P32_PGA_DRV.h"
//#include "MG82F6P32_PGA_MID.h"

//Ch29. 12-Bit ADC
#include "MG82F6P32_ADC_DRV.h"
//#include "MG82F6P32_ADC_MID.h"

//Ch30. Analog Comparator 0/1 (AC0/AC1)
#include "MG82F6P32_AC0_DRV.h"
//#include "MG82F6P32_AC0_MID.h"
#include "MG82F6P32_AC1_DRV.h"
//#include "MG82F6P32_AC1_MID.h"

//Ch31. Internal Voltage Reference (IVR, 2.4V)
//#include "MG82F6P32_IVR_DRV.h"
//#include "MG82F6P32_IVR_MID.h"

//Ch32. ISP and IAP
#include "MG82F6P32_IAP_DRV.h"
//#include "MG82F6P32_IAP_MID.h"

#endif

