/**
 ******************************************************************************
 *
 * @file        MG82F6P32_OPAx_DRV.c
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/25
 * @copyright   Copyright (c) 2019 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */
#include "MG82F6P32_CONFIG.h"
/**
*******************************************************************************
 * @brief       Read OPA0 interrupt flag.
 * @details     Set by hardware when a edge trigger.
 * @return      TRUE or FALSE
 * @note        None
 * @par         Example
 * @code
               if(DRV_OPA0_GetFlag())
                  .... //Flag=1
               else
                  .... //Flag=0
* @endcode
*******************************************************************************
*/
bool DRV_OPA0_GetFlag(void)
{
    _push_(SFRPI);
    __DRV_SFR_PageIndex(OPSTA_Page);
    if((OPSTA&OP0CMPF)==OP0CMPF)
    {
        _pop_(SFRPI);
        return TRUE;
    }
    _pop_(SFRPI);
    return FALSE;
}
/**
*******************************************************************************
 * @brief       Read OPA1 interrupt flag.
 * @details     Set by hardware when a edge trigger.
 * @return      TRUE or FALSE
 * @note        None
 * @par         Example
 * @code
               if(DRV_OPA1_GetFlag())
                  .... //Flag=1
               else
                  .... //Flag=0
* @endcode
*******************************************************************************
*/
bool DRV_OPA1_GetFlag(void)
{
    _push_(SFRPI);
    __DRV_SFR_PageIndex(OPSTA_Page);
    if((OPSTA&OP1CMPF)==OP1CMPF)
    {
        _pop_(SFRPI);
        return TRUE;
    }
    _pop_(SFRPI);
    return FALSE;
}


