/**
 ******************************************************************************
 *
 * @file        MG82F6P32_UARTx_ARGB_DRV.h
 *
 * @brief       This is the C code format driver file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     V1.00
 * @date        2024/03/27
 * @author      Megawin Software Center
 * @copyright   Copyright (c) 2024 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */


#ifndef _MG82F6P32_UARTx_ARGB_DRV_H
#define _MG82F6P32_UARTx_ARGB_DRV_H


/**
*******************************************************************************
* @brief        UART0 ARGB Reset Time Select
* @details
* @param[in]    __SELECT__ :  Set S0IDT11 and S0IDT01
 *  @arg\b      URT0_ARGB_RESET_TIME_260US : Set ARGB Reset time 260us (Default)
 *  @arg\b      URT0_ARGB_RESET_TIME_200US : Set ARGB Reset time 200us
 *  @arg\b      URT0_ARGB_RESET_TIME_60US : Set ARGB Reset time 60us
 *  @arg\b      URT0_ARGB_RESET_TIME_320US : Set ARGB Reset time 320us
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT0_ARGB_SetResetTime(URT0_ARGB_RESET_TIME_260US)
* @endcode
*******************************************************************************
*/
#define URT0_ARGB_RESET_TIME_260US          0x00       //(Default)
#define URT0_ARGB_RESET_TIME_200US          0x04
#define URT0_ARGB_RESET_TIME_60US           0x08
#define URT0_ARGB_RESET_TIME_320US          0x0C
#define __DRV_URT0_ARGB_SetResetTime(__SELECT__)\
    MWT(\
        S0AGCR = ((S0AGCR & ~URT0_ARGB_RESET_TIME_320US) | __SELECT__);\
    ;)


/**
*******************************************************************************
* @brief        Set UART0 ARGB Duty
* @details
* @param[in]    __STATE__ : Set S0DTY
 *  @arg\b      MW_DISABLE : S0DTY=0, ARGB Data Duty 1/4 (Default)
 *  @arg\b      MW_ENABLE : S0DTY=1, ARGB Data Duty 1/3
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT0_ARGB_SetDuty(MW_DISABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT0_ARGB_SetDuty(__STATE__)\
    MWT(\
        (__STATE__==MW_DISABLE?(S0DTY1=0):(S0DTY1=1));\
    ;)


/**
*******************************************************************************
* @brief        Set UART0 Mode
* @details
* @param[in]    __STATE__ : Set SM10
 *  @arg\b      MW_DISABLE : Set UART0 SM10=0 (Default)
 *  @arg\b      MW_ENABLE : Set UART0 SM10=1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT0_ARGB_SetSM10(MW_DISABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT0_ARGB_SetSM10(__STATE__)\
    MWT(\
        (__STATE__==MW_DISABLE?(SM10=0):(SM10=1));\
    ;)


/**
*******************************************************************************
* @brief        UART0 BRG Clock Source Select to SYSCLK or SYSCLK/12
* @details
* @param[in]    __STATE__ : Set S0BRG Clock Source from S0TX12
 *  @arg\b      MW_DISABLE : S0TX12=0, SYSCLK/12 (Default)
 *  @arg\b      MW_ENABLE : S0TX12=1, SYSCLK/1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT0_ARGB_SetS0BRGCLK(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT0_ARGB_SetS0BRGCLK(__STATE__)\
    MWT(\
        (__STATE__==MW_DISABLE?(S0CR1=S0CR1&~(S0TX12)):(S0CR1=S0CR1|(S0TX12)));\
    ;)


/**
*******************************************************************************
* @brief        UART0 Transmit Clock Source Select
* @details
* @param[in]    __STATE__ : Set S0TCK
 *  @arg\b      MW_DISABLE : Set UART0 S0TCK=0 (Default)
 *  @arg\b      MW_ENABLE : Set UART0 S0TCK=1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT0_ARGB_SetS0TCK(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT0_ARGB_SetS0TCK(__STATE__)\
    MWT(\
        (__STATE__==MW_DISABLE?(S0CR1=S0CR1&~(S0TCK)):(S0CR1=S0CR1|(S0TCK)));\
    ;)


/**
*******************************************************************************
* @brief        UART0 Receive Clock Source Select
* @details
* @param[in]    __STATE__ : Set S0RCK
 *  @arg\b      MW_DISABLE : Set UART0 S0RCK=0 (Default)
 *  @arg\b      MW_ENABLE : Set UART0 S0RCK=1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT0_ARGB_SetS0RCK(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT0_ARGB_SetS0RCK(__STATE__)\
    MWT(\
        (__STATE__==MW_DISABLE?(S0CR1=S0CR1&~(S0RCK)):(S0CR1=S0CR1|(S0RCK)));\
    ;)


/**
*******************************************************************************
* @brief        UART0 ARGB S0TR Operation Select
* @details
* @param[in]    __STATE__ : Set S0TR
 *  @arg\b      MW_DISABLE : S0TR=0, Stop UART0 S0BRG (Default)
 *  @arg\b      MW_ENABLE : S0TR=1, Start UART0 S0BRG
* @return       None
* @note
* @par          Example
* @code
                __DRV_URT0_ARGB_SetS0TR(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT0_ARGB_SetS0TR(__STATE__)\
    MWT(\
        (__STATE__==MW_DISABLE?(S0CR1=S0CR1&~(S0TR)):(S0CR1=S0CR1|(S0TR)));\
    ;)


/**
*******************************************************************************
* @brief        UART0 ARGB TI0 Interrupt Control
* @details
* @param[in]    __STATE__ : Set S0GFIE
 *  @arg\b      MW_DISABLE : S0GFIE=0, TI0 is normal (Default)
 *  @arg\b      MW_ENABLE : S0GFIE=1, TI0 is ignored
* @return       None
* @note
* @par          Example
* @code
                __DRV_URT0_IT_S0GFIE_Cmd(MW_DISABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT0_IT_S0GFIE_Cmd(__STATE__)\
    MWT(\
        (__STATE__==MW_DISABLE?(S0GFIE=0):(S0GFIE=1));\
    ;)


/**
*******************************************************************************
* @brief        UART1 ARGB Reset Time Select
* @details
* @param[in]    __SELECT__ : Set S1IDT11 and S1IDT01
 *  @arg\b      URT1_ARGB_RESET_TIME_260US : Set ARGB Reset time 260us (Default)
 *  @arg\b      URT1_ARGB_RESET_TIME_200US : Set ARGB Reset time 200us
 *  @arg\b      URT1_ARGB_RESET_TIME_60US : Set ARGB Reset time 60us
 *  @arg\b      URT1_ARGB_RESET_TIME_320US : Set ARGB Reset time 320us
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT1_ARGB_SetResetTime(URT1_ARGB_RESET_TIME_260US)
* @endcode
*******************************************************************************
*/
#define URT1_ARGB_RESET_TIME_260US          0x00       //(Default)
#define URT1_ARGB_RESET_TIME_200US          0x04
#define URT1_ARGB_RESET_TIME_60US           0x08
#define URT1_ARGB_RESET_TIME_320US          0x0C
#define __DRV_URT1_ARGB_SetResetTime(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(S1AGCR_Page);\
        S1AGCR = ((S1AGCR & ~URT1_ARGB_RESET_TIME_320US) | __SELECT__);\
        __DRV_SFR_PageIndex(0);\
    ;)


/**
*******************************************************************************
* @brief        Set UART1 ARGB Duty
* @details
* @param[in]    __STATE__ : Set S1DTY
 *  @arg\b      MW_DISABLE : S1DTY=0, ARGB Data Duty 1/4 (Default)
 *  @arg\b      MW_ENABLE : S1DTY=1, ARGB Data Duty 1/3
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT1_ARGB_SetDuty(MW_DISABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_ARGB_SetDuty(__STATE__)\
    MWT(\
         __DRV_SFR_PageIndex(S1AGCR_Page);\
        (__STATE__==MW_DISABLE?(S1DTY1=0):(S1DTY1=1));\
         __DRV_SFR_PageIndex(0);\
    ;)


/**
*******************************************************************************
* @brief        UART1 ARGB Mode Select
* @details
* @param[in]    __STATE__ : Set S1TME
 *  @arg\b      MW_DISABLE : Set UART0 S1TME=0 (Default)
 *  @arg\b      MW_ENABLE : Set UART0 S1TME=1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT1_ARGB_SetS1TME(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_ARGB_SetS1TME(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(S1CFG_Page);\
        (__STATE__==MW_DISABLE?(S1CFG=S1CFG&~(S1TME)):(S1CFG=S1CFG|(S1TME)));\
        __DRV_SFR_PageIndex(0);\
    ;)

/**
*******************************************************************************
* @brief        UART1 ARGB Mode Select
* @details
* @param[in]    __STATE__ : Set SM31
 *  @arg\b      MW_DISABLE : Set UART0 SM31=0 (Default)
 *  @arg\b      MW_ENABLE : Set UART0 SM31=1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT1_ARGB_SetSM31(MW_DISABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_ARGB_SetSM31(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(S1CFG_Page);\
        (__STATE__==MW_DISABLE?(S1CFG=S1CFG&~(SM31)):(S1CFG=S1CFG|(SM31)));\
        __DRV_SFR_PageIndex(0);\
    ;)


/**
*******************************************************************************
* @brief        UART1 ARGB Mode Select
* @details
* @param[in]    __STATE__ : Set SM01
 *  @arg\b      MW_DISABLE : Set UART0 SM01=0 (Default)
 *  @arg\b      MW_ENABLE : Set UART0 SM01=1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT1_ARGB_SetSM01(MW_DISABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_ARGB_SetSM01(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(S1AGCR_Page);\
        (__STATE__==MW_DISABLE?(SM01=0):(SM01=1));\
        __DRV_SFR_PageIndex(0);\
    ;)


/**
*******************************************************************************
* @brief        UART1 ARGB Mode Select
* @details
* @param[in]    __STATE__ : Set SM11
 *  @arg\b      MW_DISABLE : Set UART0 SM11=0 (Default)
 *  @arg\b      MW_ENABLE : Set UART0 SM11=1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT1_ARGB_SetSM11(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_ARGB_SetSM11(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(S1AGCR_Page);\
        (__STATE__==MW_DISABLE?(SM11=0):(SM11=1));\
        __DRV_SFR_PageIndex(0);\
    ;)


/**
*******************************************************************************
* @brief        UART1 BRG Clock Source Select to SYSCLK or SYSCLK/12
* @details
* @param[in]    __STATE__ : Set S1BRG Clock Source from S1TX12
 *  @arg\b      MW_DISABLE : S1TX12=0, SYSCLK/12 (Default)
 *  @arg\b      MW_ENABLE : S1TX12=1, SYSCLK/1
* @return       None
* @note         None
* @par          Example
* @code
                __DRV_URT1_ARGB_SetS1BRGCLK(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_ARGB_SetS1BRGCLK(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(S1CFG_Page);\
        (__STATE__==MW_DISABLE?(S1CFG=S1CFG&~(S1TX12)):(S1CFG=S1CFG|(S1TX12)));\
        __DRV_SFR_PageIndex(0);\
    ;)


/**
*******************************************************************************
* @brief        UART1 ARGB S1TR Operation Select
* @details
* @param[in]    __STATE__ : Set S1TR
 *  @arg\b      MW_DISABLE : S1TR=0, Stop UART1 S1BRG (Default)
 *  @arg\b      MW_ENABLE : S1TR=1, Start UART1 S1BRG
* @return       None
* @note
* @par          Example
* @code
                __DRV_URT1_ARGB_SetS1TR(MW_ENABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_ARGB_SetS1TR(__STATE__)\
    MWT(\
         __DRV_SFR_PageIndex(S1CFG_Page);\
        (__STATE__==MW_DISABLE?(S1CFG=S1CFG&~(S1TR)):(S1CFG=S1CFG|(S1TR)));\
        __DRV_SFR_PageIndex(0);\
    ;)



/**
*******************************************************************************
* @brief        UART1 ARGB TI1 Interrupt Control
* @details
* @param[in]    __STATE__ : Set S1GFIE
 *  @arg\b      MW_DISABLE : S1GFIE=0, TI1 is normal (Default)
 *  @arg\b      MW_ENABLE : S1GFIE=1, TI1 is ignored
* @return       None
* @note
* @par          Example
* @code
                __DRV_URT1_IT_S1GFIE_Cmd(MW_DISABLE)
* @endcode
*******************************************************************************
*/
#define __DRV_URT1_IT_S1GFIE_Cmd(__STATE__)\
    MWT(\
         __DRV_SFR_PageIndex(S1AGCR_Page);\
        (__STATE__==MW_DISABLE?(S1GFIE=0):(S1GFIE=1));\
        __DRV_SFR_PageIndex(0);\
    ;)



#endif  //_MG82F6P32_UARTx_ARGB_DRV_H



